@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 # Copyright 2015 Sam Yaple
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -51,8 +49,6 @@ class DockerWorker(object):
 
         self._cgroupns_mode_supported = (
             StrictVersion(self.dc._version) >= StrictVersion('1.41'))
-        self._dimensions_kernel_memory_removed = (
-            StrictVersion(self.dc._version) >= StrictVersion('1.42'))
 
     def generate_tls(self):
         tls = {'verify': self.params.get('tls_verify')}
@@ -310,11 +306,8 @@ class DockerWorker(object):
             'memswap_limit': 'MemorySwap', 'cpu_period': 'CpuPeriod',
             'cpu_quota': 'CpuQuota', 'cpu_shares': 'CpuShares',
             'cpuset_cpus': 'CpusetCpus', 'cpuset_mems': 'CpusetMems',
-            'blkio_weight': 'BlkioWeight', 'ulimits': 'Ulimits'}
-
-        if not self._dimensions_kernel_memory_removed:
-            dimension_map['kernel_memory'] = 'KernelMemory'
-
+            'kernel_memory': 'KernelMemory', 'blkio_weight': 'BlkioWeight',
+            'ulimits': 'Ulimits'}
         unsupported = set(new_dimensions.keys()) - \
             set(dimension_map.keys())
         if unsupported:
