@@ -127,11 +127,6 @@ def check_json_j2():
             'api_interface_address': '',
             'kolla_internal_fqdn': '',
             'octavia_provider_drivers': '',
-            'storage_interface': 'storage_interface',
-            'rabbitmq_ha_replica_count': 2,
-            'rabbitmq_message_ttl_ms': 600000,
-            'rabbitmq_queue_expiry_ms': 3600000,
-
         }
         data = template.render(**context)
         json.loads(data)
